=====================
django-migrations-tui
=====================

Manage Django Migrations with a Text-Based UI

Installation
------------
``django-migrations-tui`` is available on PyPI and can be installed with ``pip``:

.. code-block:: console

    pip install django-migrations-tui

Quick start
-----------

1. Add ``django_migrations_tui`` to your ``INSTALLED_APPS``.
2. Run ``python manage.py migrationstui`` to start the UI.

Screenshot
----------

.. image:: https://user-images.githubusercontent.com/3104974/273346792-8f6ee764-4283-4fa2-b311-733a2d363e91.png
    :alt: Screenshot of django-migrations-tui
    :align: center
    :width: 600px
    :target: https://user-images.githubusercontent.com/3104974/273346792-8f6ee764-4283-4fa2-b311-733a2d363e91.png
